BLNUHR: Python & Qt rendition of Berlin's quantity didactics clock
==================================================================

*blnuhr*: Python & Qt rendition of Berlin's quantity didactics clock

:docs: http://blnuhr.readthedocs.org
:git:  https://github.com/prjemian/blnuhr/

http://www.surveyor.in-berlin.de/berlin/uhr/indexe.html
The Berlin quantity didactics clock
